# Install Python and pip

1. Download and install [Python 3.10+](https://www.python.org/downloads/release/python-3100/).
2. During installation, make sure to check the box **"Add Python to PATH"**.
3. You can verify the installation by running the following command in the terminal:

   ```
   python --version
   ```

   The correct responce may be next:

   ```
   Python 3.10.12
   ```

   _Though the version may vary_.
